@@ -1,6 +1,6 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2005-2007 Andrey Korotaev <unC0Rr@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2005-2010 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,24 +20,33 @@
 #include <QDir>
 #include <QStringList>
 #include <QColor>
+#include <QPair>
 
 extern QString * cProtoVer;
+extern QString * cVersionString;
 extern QString * cDataDir;
+extern QString * cConfigDir;
 
 extern QDir * bindir;
 extern QDir * cfgdir;
 extern QDir * datadir;
 
+extern bool custom_config;
+extern bool custom_data;
+
+extern int cMaxTeams;
+
 extern QStringList * Themes;
+extern QStringList * mapList;
 
 extern QString * cDefaultAmmoStore;
+extern int cAmmoNumber;
+extern QList< QPair<QString, QString> > cDefaultAmmos;
 
-extern QColor * color1;
-extern QColor * color2;
-extern QColor * color3;
-extern QColor * color4;
-extern QColor * color5;
-extern QColor * color6;
+extern QColor *colors[];
 
 extern QString * netHost;
 extern quint16 netPort;
+
+extern bool haveServer;
+extern bool isDevBuild;
