@@ -1,6 +1,6 @@
 /*
- * Hedgewars, a worms-like game
- * Copyright (c) 2006 Andrey Korotaev <unC0Rr@gmail.com>
+ * Hedgewars, a free turn based strategy game
+ * Copyright (c) 2006-2010 Andrey Korotaev <unC0Rr@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,16 +25,25 @@ HWProto::HWProto()
 
 QByteArray & HWProto::addStringToBuffer(QByteArray & buf, const QString & string)
 {
-	QByteArray strmsg = string.toUtf8();
-	quint8 sz = strmsg.size();
-	buf.append(QByteArray((char *)&sz, 1));
-	buf.append(strmsg);
-	return buf;
+    QByteArray strmsg = string.toUtf8();
+    strmsg = strmsg.left(250);
+    quint8 sz = strmsg.size();
+    buf.append(QByteArray((char *)&sz, 1));
+    buf.append(strmsg);
+    return buf;
 }
 
 QByteArray & HWProto::addStringListToBuffer(QByteArray & buf, const QStringList & strList)
 {
-	for (int i = 0; i < strList.size(); i++)
-		addStringToBuffer(buf, strList[i]);
-	return buf;
+    for (int i = 0; i < strList.size(); i++)
+        addStringToBuffer(buf, strList[i]);
+    return buf;
+}
+
+QString HWProto::formatChatMsg(const QString & nick, const QString & msg)
+{
+    if(msg.left(4) == "/me ")
+        return QString("\x02* %1 %2").arg(nick).arg(msg.mid(4));
+    else
+        return QString("\x01%1: %2").arg(nick).arg(msg);
 }
